@@ -14,6 +14,7 @@ pub struct ParsedResult {
     pub languages: Vec<Language>,
 }
 
+const CLASSIFICATION_INDEX: u32 = 0;
 const ATTR_NAME_INDEX: u32 = 1;
 const ATTR_TYPE_INDEX: u32 = 2;
 const PII_FLAG_INDEX: u32 = 3;
@@ -64,6 +65,13 @@ pub fn parse(path: String) -> Result<ParsedResult, Box<dyn std::error::Error>> {
 
     let mut oca_builder = OCABuilder::new(Encoding::Utf8);
 
+    let mut classification = String::new();
+    let classification_value = main_sheet.get_value((oca_range.0, CLASSIFICATION_INDEX));
+    if let Some(class) = classification_value {
+        classification = class.to_string();
+    }
+    oca_builder = oca_builder.add_classification(classification);
+
     let mut attribute_names = vec![];
     let mut attribute_builders: Vec<(u32, AttributeBuilder)> = vec![];
     for attr_index in oca_range.0..oca_range.1 {
@@ -88,8 +96,9 @@ pub fn parse(path: String) -> Result<ParsedResult, Box<dyn std::error::Error>> {
             ))
             .or_else(|e| {
                 Err(format!(
-                    "Parsing attribute type in row {} failed. {}",
+                    "Parsing attribute type in row {} ({}) failed. {}",
                     attr_index + 1,
+                    attribute_name,
                     e.to_string()
                 ))
             })?,
@@ -119,20 +128,22 @@ pub fn parse(path: String) -> Result<ParsedResult, Box<dyn std::error::Error>> {
         if let Some(DataType::String(entry_codes_value)) =
             main_sheet.get_value((attr_index, ENTRY_CODES_INDEX))
         {
-            let entry_codes: EntryCodes;
-            if entry_codes_value.starts_with("SAI:") {
-                let sai = entry_codes_value.strip_prefix("SAI:").unwrap();
-                entry_codes = EntryCodes::Sai(sai.to_string());
-            } else {
-                let codes: Vec<String> = entry_codes_value
-                    .split("|")
-                    .collect::<Vec<&str>>()
-                    .iter()
-                    .map(|c| c.to_string())
-                    .collect();
-                entry_codes = EntryCodes::Array(codes);
+            if entry_codes_value != &"[SAI]".to_string() {
+                let entry_codes: EntryCodes;
+                if entry_codes_value.starts_with("SAI:") {
+                    let sai = entry_codes_value.strip_prefix("SAI:").unwrap();
+                    entry_codes = EntryCodes::Sai(sai.to_string());
+                } else {
+                    let codes: Vec<String> = entry_codes_value
+                        .split("|")
+                        .collect::<Vec<&str>>()
+                        .iter()
+                        .map(|c| c.to_string())
+                        .collect();
+                    entry_codes = EntryCodes::Array(codes);
+                }
+                attribute_builder = attribute_builder.add_entry_codes(entry_codes);
             }
-            attribute_builder = attribute_builder.add_entry_codes(entry_codes);
         }
         attribute_builders.push((attr_index, attribute_builder));
     }
@@ -246,7 +257,10 @@ pub fn parse(path: String) -> Result<ParsedResult, Box<dyn std::error::Error>> {
                                 let lang_entry = &mut entry_vec
                                     .iter_mut()
                                     .find(|el| &el.id == e_key)
-                                    .unwrap()
+                                    .ok_or(format!(
+                                        "Unknown entry code in {} translation: {}",
+                                        lang, e_key
+                                    ))?
                                     .translations;
                                 lang_entry.insert(lang.to_string(), e_val.clone());
                             }
